#
# spec file for package giggle
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           giggle
Version:        0.7
Release:        lp152.3.9
Summary:        A graphical frontend for git
License:        GPL-2.0+
Group:          Development/Tools/Version Control
Url:            http://live.gnome.org/giggle
Source:         http://ftp.acc.umu.se/pub/GNOME/sources/giggle/0.7/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM giggle-gtksourceview38.patch bgo#697220 dimstar@opensuse.org -- Fix build against gtksourceview 3.8
Patch0:         giggle-gtksourceview38.patch
# PATCH-FIX-UPSTREAM giggle-vte-2.91.patch zaitor@opensuse.org -- Fix build with vte-2.91. Patch from archlinux.
Patch1:         giggle-vte-2.91.patch
BuildRequires:  gettext >= 0.18.1
BuildRequires:  git-core >= 1.5
BuildRequires:  intltool
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.30
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(gtksourceview-3.0) >= 3.0
BuildRequires:  pkgconfig(vte-2.91) >= 0.26
Recommends:     %{name}-lang
Requires:       git-core >= 1.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Giggle is a Gtk frontend to the git content tracker.

With Giggle you will be able to visualize and browse easily the revision
tree, view changed files and differences between revisions, visualize
summarized info for the project, commit changes and other useful tasks
for any git managed projects contributor.

%package devel
Summary:        A graphical frontend for git
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}

%description devel
Giggle is a Gtk frontend to the git content tracker.

With Giggle you will be able to visualize and browse easily the revision
tree, view changed files and differences between revisions, visualize
summarized info for the project, commit changes and other useful tasks
for any git managed projects contributor.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
translation-update-upstream po giggle

%build
%configure
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -G "Git repository viewer" %{name}

%if 0%{?suse_version} <= 1210
# Localized help
for help in %{buildroot}%{_datadir}/help/*/%{name}/; do
    LOCALE=`echo $help | sed "s:.*%{_datadir}/help/\([^/]*\)/%{name}/:\1:g"`
    echo "%%lang($LOCALE) %%dir %%{_datadir}/help/$LOCALE" >> %{name}.help-lang.tmp
    echo "%%lang($LOCALE) %%doc /${help##%{buildroot}}" >> %{name}.help-lang.tmp
done
echo "%%defattr(-,root,root)" >> %{name}.lang
sort -u %{name}.help-lang.tmp | grep -v "^%%lang(C)" >> %{name}.help-lang
%endif

%clean
rm -rf %{buildroot}

%post
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_post
%icon_theme_cache_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%defattr(-, root, root)
%doc AUTHORS COPYING INSTALL NEWS README
%{_bindir}/*
%{_datadir}/applications/*.desktop
%doc %dir %{_datadir}/help
%doc %dir %{_datadir}/help/C
%doc %{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/*/*/*.svg
%{_libdir}/libgiggle.so.*
%{_libdir}/libgiggle-git.so.*
%dir %{_libdir}/giggle
%dir %{_libdir}/giggle/plugins
%dir %{_libdir}/giggle/plugins/%{version}
%{_libdir}/giggle/plugins/%{version}/*.so
%{_libdir}/giggle/plugins/%{version}/*.xml
%{_datadir}/giggle/

%files lang -f %{name}.lang

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/libgiggle.so
%{_libdir}/libgiggle-git.so

%changelog
* Fri Oct 10 2014 zaitor@opensuse.org
- Add giggle-vte-2.91.patch: Fix build with vte-2.91
- Replace pkgconfig(vte-2.90) for pkgconfig(vte-2.91), due to above
  patch.
* Wed Apr 17 2013 dimstar@opensuse.org
- Fix giggle-gtksourceview38.patch: gtksource 3.8 change the main
  header from gtksourceview.h to gtksource.h.
* Wed Apr  3 2013 dimstar@opensuse.org
- Add giggle-gtksourceview38.patch: Fix build against new
  gtksourceview 3.8.
* Wed Nov  7 2012 douglarek@outlook.com
- Update to version 0.7:
  + Bump minimum GLib required version to 2.30
  + build: Depends on gettext 0.18.1
  + Use G_VALUE_INIT
  + Use g_cclosure_marshal_generic for all signals
  + Use g_clear_object() and g_list_free_full() convenience
    functions
  + Use GtkGrid instead GtkTable
  + Use GDK symbolic names
  + Use gdk_event_triggers_context_menu() instead of check for
    event->button == 3
  + Update FSF Address
  + Do not use deprecated libebook api
  + build: Use the gnulib manywarnings macros
  + src/giggle-revision-view.c: Use a GtkLabel instead a
    GtkLinkButton
- Add gettext BuildRequires: new versioned dependency.
- Drop pkgconfig(libebook-1.2) BuildRequires: no longer needed.
* Thu Nov  1 2012 douglarek@outlook.com
- Update to version 0.6.2:
  + build: Explicitly link to gmodule-2.0.
  + use the giggle api instead g_object_get()
- Drop giggle-link-gmodule.patch: fixed upstream.
- Drop xz BuildRequires as it now comes for free in the build
  system.
- Only conditionally use find_lang variant on openSUSE <= 12.1.
* Sun Feb 26 2012 vuntz@opensuse.org
- Change itstool BuildRequires to yelp-tools: this is really what
  is needed for build.
* Thu Jan 19 2012 vuntz@opensuse.org
- Fix build by explictly linking to gmodule-2.0:
  + Add giggle-link-gmodule.patch.
  + Add gnome-common BuildRequires and call to gnome-autogen.sh,
    needed for above patch.
* Tue Nov 15 2011 dimstar@opensuse.org
- Update to version 0.6.1:
  + Several bugfixes
  + Updated translations.
- Changes from version 0.6:
  + Port to GTK+3
  + Added new mallard documentation
  + Establish giggle as url-handler for git:// links
  + Allow diff view to display diffs by chunks, files or all
  + Several bugfixes
- Drop giggle-ld_fix.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh.
- Replace pkgconfig(gtk+-2.0) with pkgconfig(gtk+-3.0),
  pkgconfig(gtksourceview-2.0) with pkgconfig(gtksourceview-3.0)
  and pkgconfig(vte) with pkgconfig(vte-2.90), following upstream
  changes.
- Add itstool BuildRequires.
- Add localized help to -lang package. Install section inspired by
  aisleriot, which does the same.
* Mon Sep 19 2011 vuntz@opensuse.org
- Update giggle-ld_fix.patch to the upstream fix.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  needed for the patch.
- Remove now unneeded export SUSE_ASNEEDED=0.
* Sat Sep 17 2011 suse-tux@gmx.de
- Add giggle-ld_fix.patch to fix build with new ld behavior.
* Thu Apr 28 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: evolution-data-server-devel, gtk2-devel,
    gtksourceview-devel, vte-devel.
  + New ones: glib-2.0, gtk+-2.0, gtksourceview-2.0, libebook-1.2,
    vte.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Thu Aug 12 2010 vuntz@opensuse.org
- Update to version 0.5:
  + Several performance improvements
  + Fix crash when searching
  + Improve responsiveness when executing git commands
  * Some memory fixes
  + Updated translations.
* Thu Apr  1 2010 vuntz@opensuse.org
- Clean up packaging from Contrib for inclusion in Factory:
  + Drop giggle-0.4-desktop.patch and instead use options of
    suse_update_desktop_file.
  + Drop libglade2-devel, perl-XML-Parser BuildRequires.
  + Improve description.
  + Requires git-core instead of git.
* Thu Apr  1 2010 prusnak@suse.cz
- updated to 0.4.97
* Tue Feb 24 2009 prusnak@suse.cz
- updated to 0.4.91
* Tue Oct 23 2007 maw@suse.de
- initial package (version 0.3)
